# devtools::load_all()

knitr::knit("vignettes/consistency.Rmd.orig",
            "vignettes/consistency.Rmd")

knitr::knit("vignettes/gd.Rmd.orig",
            "vignettes/gd.Rmd")

knitr::knit("vignettes/opgd.Rmd.orig",
            "vignettes/opgd.Rmd")

knitr::knit("vignettes/sesu.Rmd.orig",
            "vignettes/sesu.Rmd")

knitr::knit("vignettes/shegd.Rmd.orig",
            "vignettes/shegd.Rmd")

knitr::knit("vignettes/spade.Rmd.orig",
            "vignettes/spade.Rmd")

knitr::knit("vignettes/idsa.Rmd.orig",
            "vignettes/idsa.Rmd")

knitr::knit("vignettes/rgdrid.Rmd.orig",
            "vignettes/rgdrid.Rmd")
